@@ -2,11 +2,18 @@ from dataclasses import dataclass, field
 from pathlib import Path
 from typing import Union, Optional, List
 
+from arrow_dmn.engine.sync_dmn_engine import SyncDmnEngine
+
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.__spi__.execution.event_emitter import EventEmitter
 from arrow_bpmn.__spi__.execution.incident_handler import IncidentHandler, LoggingIncidentHandler
+from arrow_bpmn.__spi__.factory import BpmnFactories, ServiceFactory
+from arrow_bpmn.__spi__.factory.business_rule_factory import BusinessRuleFactory
+from arrow_bpmn.__spi__.factory.script_factory import ScriptFactory
+from arrow_bpmn.__spi__.factory.service_factory import NoOpServiceFactory
 from arrow_bpmn.__spi__.registry.event import Event
 from arrow_bpmn.engine.event.eager_event_emitter import EagerEventEmitter
+from arrow_bpmn.engine.execution.cacheable_script_factory import CacheableScriptFactory
 from arrow_bpmn.engine.listener.abstract_bpmn_engine_listener import BpmnEngineListener
 from arrow_bpmn.engine.registry.abstract_event_registry import EventRegistry, ProcessRef
 from arrow_bpmn.engine.registry.inmemory_event_registry import InMemoryEventRegistry
@@ -26,6 +33,12 @@ class BpmnEngine:
     listeners: List[BpmnEngineListener] = field(default_factory=lambda: [])
     incident_handler: IncidentHandler = field(default_factory=lambda: LoggingIncidentHandler())
     event_emitter: EventEmitter = field(default_factory=lambda: EagerEventEmitter())
+    script_factory: ScriptFactory = field(default_factory=lambda: CacheableScriptFactory(128))
+    service_factory: ServiceFactory = field(default_factory=lambda: NoOpServiceFactory())
+    business_rule_factory: BusinessRuleFactory = field(default_factory=lambda: SyncDmnEngine())
+
+    def __post_init__(self):
+        self.factories = BpmnFactories(self.script_factory, self.service_factory, self.business_rule_factory)
 
     def deploy(self, source: BpmnSource) -> List[ProcessRef]:
         deployed_processes = []
