@@ -1,4 +1,5 @@
 import logging
+import uuid
 from typing import List, Optional
 
 from arrow_bpmn.__spi__ import CompleteAction, IncidentAction
@@ -29,7 +30,7 @@ class SequentialBpmnEngine(BpmnEngine):
     def invoke_by_event(self, event: Event, init_state: Optional[dict] = None) -> List[State]:
         def invoke(subscription: NodeRef):
             process = self.process_store.read_process(ProcessRef(event.group, subscription.process_id))
-            environment = Environment(event.group, process)
+            environment = Environment(event.group, process, self.factories)
 
             is_reentry = not environment.is_start_event(subscription.node_id)
             state = State(init_state or {}, subscription, is_reentry)
@@ -46,7 +47,7 @@ class SequentialBpmnEngine(BpmnEngine):
         def resume_process(node_ref: NodeRef) -> List[State]:
             state = self.process_store.read_state(node_ref)
             process = self.process_store.read_process(ProcessRef(event.group, node_ref.process_id))
-            environment = Environment(event.group, process)
+            environment = Environment(event.group, process, self.factories)
 
             action = ContinueAction(node_ref.node_id)
             return self._handle_action(action, state, environment)
@@ -65,7 +66,9 @@ class SequentialBpmnEngine(BpmnEngine):
         if isinstance(action, ContinueAction):
             node = env.get_node(action.id)
             assert node is not None, f"no node found with id {action.id}"
-            new_state = state.with_reference(NodeRef(state.reference.process_id, action.id))
+
+            node_ref = NodeRef(env.group, state.reference.process_id, action.id, str(uuid.uuid4()), str(uuid.uuid4()))
+            new_state = state.with_reference(node_ref)
 
             # execute all present boundary events in order to register their events
             [self._handle_action(ContinueAction(e.id), state, env) for e in env.get_boundary_events(node.id)]
@@ -84,8 +87,7 @@ class SequentialBpmnEngine(BpmnEngine):
                 self._handle_action(DequeueAction(event.attached_to_ref), state, env)
 
             if action.save_state:
-                node = env.get_node(action.id)
-                print("save " + str(node))
+                self.process_store.write_state(state)
 
             if action.consume_token:
                 return [state]
@@ -96,8 +98,7 @@ class SequentialBpmnEngine(BpmnEngine):
         # ************
         elif isinstance(action, QueueAction):
             if action.save_state:
-                node = env.get_node(action.id)
-                print("save " + str(node))
+                self.process_store.write_state(state)
 
             if action.event is not None:
                 # register an event subscription to get ready for an ResumeAction
@@ -122,7 +123,7 @@ class SequentialBpmnEngine(BpmnEngine):
 
             process = self.process_store.read_process(ProcessRef(event.group, subscription.process_id))
             new_state = State(action.init_state, subscription, False, action.parent_reference)
-            new_environment = Environment(event.group, process)
+            new_environment = Environment(event.group, process, self.factories)
 
             new_state = first(self._handle_action(ContinueAction(subscription.node_id), new_state, new_environment))
             return self._handle_action(ResumeAction(new_state.parent_reference), new_state, env)
@@ -133,7 +134,7 @@ class SequentialBpmnEngine(BpmnEngine):
             _env = env
             if action.reference.process_id != env.process_id:
                 parent_process = self.process_store.read_process(ProcessRef(env.group, action.reference.process_id))
-                _env = Environment(env.group, parent_process)
+                _env = Environment(env.group, parent_process, self.factories)
 
             node = _env.get_node(action.reference.node_id)
             assert node is not None, f"no node found with id {action.reference.node_id}"
