@@ -8,7 +8,7 @@ class ProcessStore:
     def write_process(self, group: str, process: Process):
         pass
 
-    def read_process(self, ref: ProcessRef):
+    def read_process(self, ref: ProcessRef) -> Process:
         pass
 
     def write_state(self, state: State):
