@@ -6,7 +6,6 @@ from arrow_bpmn.__spi__.action import ContinueAction, Actions, EventAction
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.engine.registry.abstract_event_registry import MessageEvent
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class SendTask(BpmnNode):
@@ -14,7 +13,7 @@ class SendTask(BpmnNode):
     A Send Task is used to send a message.
     """
 
-    def __init__(self, element: XMLElement):
+    def __init__(self, element: dict):
         super().__init__(element)
 
     @property
