@@ -17,6 +17,7 @@ from arrow_bpmn.model.event.startevent.signal_start_event import SignalStartEven
 from arrow_bpmn.model.gateway.exclusive_gateway import ExclusiveGateway
 from arrow_bpmn.model.process import Process, EventDict
 from arrow_bpmn.model.sequence.sequence_flow import SequenceFlow
+from arrow_bpmn.model.task.business_rule_task import BusinessRuleTask
 from arrow_bpmn.model.task.call_activity import CallActivity, VariableMapping, ExpressionMapping
 from arrow_bpmn.model.task.manual_task import ManualTask
 from arrow_bpmn.model.task.receive_task import ReceiveTask
@@ -43,15 +44,16 @@ class XmlBpmnParser(BpmnParser):
         return "customGroup", [self._parse_process(x, events) for x in root.get_tags("./bpmn:process")]
 
     def _parse_process(self, process: XMLElement, events: EventDict) -> Process:
-        sequence_flows = [SequenceFlow(x, self.script_factory) for x in process.get_tags("bpmn:sequenceFlow")]
-        tasks = [ScriptTask(x, self.script_factory) for x in process.get_tags("bpmn:scriptTask")]
-        tasks += [UserTask(x) for x in process.get_tags("bpmn:userTask")]
-        tasks += [ManualTask(x) for x in process.get_tags("bpmn:manualTask")]
-        tasks += [ReceiveTask(x) for x in process.get_tags("bpmn:receiveTask")]
-        tasks += [SendTask(x) for x in process.get_tags("bpmn:sendTask")]
-        tasks += [ServiceTask(x, self.service_factory) for x in process.get_tags("bpmn:serviceTask")]
+        sequence_flows = [SequenceFlow.from_xml(x) for x in process.get_tags("bpmn:sequenceFlow")]
+        tasks = [ScriptTask.from_xml(x) for x in process.get_tags("bpmn:scriptTask")]
+        tasks += [UserTask(x.get_attributes()) for x in process.get_tags("bpmn:userTask")]
+        tasks += [ManualTask(x.get_attributes()) for x in process.get_tags("bpmn:manualTask")]
+        tasks += [ReceiveTask(x.get_attributes()) for x in process.get_tags("bpmn:receiveTask")]
+        tasks += [SendTask(x.get_attributes()) for x in process.get_tags("bpmn:sendTask")]
+        tasks += [ServiceTask(x) for x in process.get_tags("bpmn:serviceTask")]
+        tasks += [BusinessRuleTask.from_xml(x) for x in process.get_tags("bpmn:businessRuleTask")]
         tasks += [self._parse_call_activity(x) for x in process.get_tags("bpmn:callActivity")]
-        tasks += [self._parse_custom_task(x) for x in process.get_tags("bpmn:task")]
+        tasks += [self._parse_custom_task(x, events) for x in process.get_tags("bpmn:task")]
         start_events = [self._parse_start_event(x, events) for x in process.get_tags("bpmn:startEvent")]
         end_events = [self._parse_end_event(x, events) for x in process.get_tags("bpmn:endEvent")]
         boundary_events = [self._parse_boundary_event(x, events) for x in process.get_tags("bpmn:boundaryEvent")]
